@@ -6,8 +6,7 @@
 
 use clap::Parser;
 use unit_conversions::time;
-use colorful::Colorful;
-use colorful::Color;
+use recolored::*;
 
 #[derive(Parser, Debug)]
 #[clap(name = "didu", version, about="Duration conversion between units")]
@@ -81,7 +80,7 @@ fn main() {
 
     // Print the duration(s) with the input unit if the only-result option is false.
     if only_result == false {
-        println!("{} {} {}", input_value.to_string().color(Color::Yellow).bold().underlined(), input_unit.color(Color::Green).bold(), "are:" );
+        println!("{} {} {}", input_value.to_string().yellow().bold(), input_unit.green().bold(), "are:" );
     };
 
     let options = match output_unit.as_str() {
@@ -232,31 +231,31 @@ fn main() {
     } else {
         // …with unit indicator(s).
         if options.seconds {
-            println!("{:.1$} {2}", seconds, precision, "s".color(Color::Blue));
+            println!("{:.1$} {2}", seconds, precision, "s".blue());
         }
         if options.minutes  {
-            println!("{:.1$} {2}", minutes, precision, "min".color(Color::Blue));
+            println!("{:.1$} {2}", minutes, precision, "min".blue());
         }
         if options.hours  {
-            println!("{:.1$} {2}", hours, precision, "h".color(Color::Blue));
+            println!("{:.1$} {2}", hours, precision, "h".blue());
         }
         if options.days  {
-            println!("{:.1$} {2}", days, precision, "d".color(Color::Blue));
+            println!("{:.1$} {2}", days, precision, "d".blue());
         }
         if options.weeks  {
-            println!("{:.1$} {2}", weeks, precision, "w".color(Color::Blue));
+            println!("{:.1$} {2}", weeks, precision, "w".blue());
         }
         if options.months  {
-            println!("{:.1$} {2}", months, precision, "m".color(Color::Blue));
+            println!("{:.1$} {2}", months, precision, "m".blue());
         }
         if options.years  {
-            println!("{:.1$} {2}", years, precision, "y".color(Color::Blue));
+            println!("{:.1$} {2}", years, precision, "y".blue());
         }
         if options.decades  {
-            println!("{:.1$} {2}", decades, precision, "dec".color(Color::Blue));
+            println!("{:.1$} {2}", decades, precision, "dec".blue());
         }
         if options.centuries  {
-            println!("{:.1$} {2}", centuries, precision, "cen".color(Color::Blue));
+            println!("{:.1$} {2}", centuries, precision, "cen".blue());
         }
     };
 }
